@@ -17,14 +17,6 @@ class NotNegativeInteger(Base):
         self.name = f'_{name.lower()}'
 
 
-class A:
-    a = NotNegativeInteger()
-
-ar = A()
-ar.a = 5
-print(ar.a)
-
-
 class NotPositiveInteger(Base):
 
     def __get__(self, instance, owner):
